<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el_GR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Κάθετη περιστροφή</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Οριζόντια περιστροφή</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Αντιστροφή</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Ασπρόμαυρη</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Εναλλαγή σε Παράθυρο</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Εναλλαγή σε Πλήρη οθόνη</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Η εγκατάσταση ήταν επιτυχημένη</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Κλείστε αυτό το παράθυρο και ξεκινήστε το vokoscreenNG ξανά.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Διασκεδάστε με το vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Προειδοποίηση</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Η εγγραφή δε ξεκίνησε, μη επαρκής ελεύθερος χώρος στο δίσκο.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Φτάσατε το όριο ελεύθερου χώρου στο δίσκο.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Όριο ελεύθερου χώρου στο δίσκο.</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Η εγγραφή σταμάτησε, μη επαρκής ελεύθερος χώρος στο δίσκο.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Πηγαίος κώδικας</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Αρχική</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Μεταφράσεις</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Δωρεά</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Πηγαίος κώδικας</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Αρχική</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Μεταφράσεις</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Δωρεά</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχιση</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Μεγένθυση</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχιση</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Μεγένθυση</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Οριζόντια περιστροφή</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Κάθετη περιστροφή</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Αντιστροφή</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Ασπρόμαυρη</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ρυθμίσεις Κάμερας</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Επαναφορά</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Μεγένθυση</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Αντίστροφη μέτρηση</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Μέγεθος βίντεο:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ελεύθερος χώρος στο δίσκο:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Χρόνος Εγγραφής:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>&apos;Ηχος</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Στιγμιότυπα</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Κωδικοποιητής βίντεο</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Τύπος αρχείου</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Κωδικοποιητής ήχου</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Μην καταγράφεις τον κέρσορα</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ώρα</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Λεπτό</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Ενεργοποίηση του χρονοδιακόπτη</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Διακοπή εγγραφής μετά από</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ώρες</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Λεπτά</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Δευτερόλεπτα</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Τοποθεσία αρχείου</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Όριο ελεύθερου χώρου στο δίσκο.</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Εμφάνιση στην περιοχή ειδοποιήσεων</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Δευτερόλεπτα αναμονής πριν την εγγραφή</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Έλεγχος για ενημερώσεις</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Διαθέσιμο</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Μη διαθέσιμο</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχιση</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Φάκελος</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Αντιστροφή</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Αναπαραγωγή τελευταίας εγγραφής</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Ελαχιστοποίηση όταν ξεκινά η εγγραφή</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Εκκίνηση σε ελαχιστοποίηση</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Οριζόντια περιστροφή</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Κάθετη περιστροφή</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Ασπρόμαυρη</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Επαναφορά όλων των ρυθμίσεων στην επόμενη εκκίνηση</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Πνευματικά δικαιώματα και άδεια από τις φωτογραφίες</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Μεγαμπάιτ</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Αναμετάδοση οθόνης</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Αναπαραγωγή με</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Αρχείο καταγραφής</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>αυτόματα</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Δημιουργία εικόνων των καρτελών</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Πληροφορίες για την άδεια χρήσης</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ΟΝ</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>ΟFF</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Συντομεύσεις πληκτρολογίου</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Πλήκτρα με αντιστοίχιση</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Δεν υπάρχει καμμία αντιστοίχηση πληκτρολογίου ή υπάρχουν περισσότερες από μία</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Αν έχει ένδειξη αντιστοίχισης αλλά δεν λειτουργεί, τότε χρησιμοποιείται από κάποιο άλλο πρόγραμμα.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Στιγμιότυπο</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Διαδρομή αποθήκευσης εικόνων</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Κρύψιμο αυτού του παραθύρου</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Δευτερόλεπτα αναμονής πριν την έναρξη της εγγραφής</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Πνευματικά δικαιώματα και άδεια από τις φωτογραφίες</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Δημιουργία εικόνων των καρτελών</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Πληροφορίες για την άδεια χρήσης</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ΟΝ</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>ΟFF</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Χρόνος Εγγραφής:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Μέγεθος βίντεο:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ελεύθερος χώρος στο δίσκο:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Κωδικοποιητής βίντεο</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Στιγμιότυπα</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Τύπος αρχείου</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Διαθέσιμο</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Μη διαθέσιμο</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Φάκελος</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Μην καταγράφεις τον κέρσορα</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Κωδικοποιητής ήχου</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Τοποθεσία αρχείου</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Αντίστροφη μέτρηση</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Αντιστροφή</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Ασπρόμαυρη</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Κάθετη περιστροφή</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Οριζόντια περιστροφή</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Δευτερόλεπτα αναμονής πριν την εγγραφή</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Επαναφορά</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Κρύψιμο αυτού του παραθύρου</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Δευτερόλεπτα αναμονής πριν την έναρξη της εγγραφής</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Πνευματικά δικαιώματα και άδεια από τις φωτογραφίες</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
</context>
</TS>